// Views.FormAux.cs

// Version 1.28;  20 August 2005
// Copyright (C) 2004  Robert Nigel Horspool

/*

Views: Vendor Independent Extensible Windowing System
=====================================================

Queries to views@cs.up.ac.za
See http://views.cs.up.ac.za for
   - user and developer lists
   - new developments

A joint project of University of Victoria, Canada and
                    University of Pretoria, South Africa
Begun February 2002

Designed by
     Nigel Horspool (nigelh@uvic.ca)
     Judith Bishop (jbishop@cs.up.ac.za)

Original Windows implementation 2002-2003
   Nigel Horspool (nigelh@uvic.ca)

New implementation for Qt 2004
   Basil Worrall (bworrall@cs.up.ac.za)
   D-J Miller (anoyomouse@hotmail.com)

Port of Views on Qt to Linux
   University of Karlsruhe, June 2004
   Mihael Vrbanec (miqster@gmx.net)
   Johannes Eickhold (JEickhold@gmx.de)
   Matthias Kempka (mkempka@mkempka.de)

Initiated under the Microsoft Research Rotor RFP-1 Initiative

-----------

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

namespace Views 
{

using System;
using System.Drawing;
using System.Collections;
using System.Data;

	// Class to keep a bit more information about the controls created by Views
	public class VControl {
		public string tag;	// the XML tagname
		public Size ds;		// the desired size of the group or control
		public Size fs;		// the final size of the group or control
		public string halign;	// "left", "right" or "centre"
		public string valign;	// "top", "bottom" or "middle"

		public System.Windows.Forms.Control c;	// the control we created
		public bool positionSet;
		public bool alignmentSet;

		public VControl(string t, System.Windows.Forms.Control cc) : this(t) {
			c = cc;
		}

		public VControl(string t) : this() {
			tag = t;
		}

		public override string ToString() {
			return String.Format("VControl (tag={0})", tag);
		}

		public VControl() {
			positionSet = false;
			alignmentSet = false;
			ds = new Size(0,0);
			fs = new Size(0,0);
			halign = "left"; valign = "top";
		}

		public static implicit operator System.Windows.Forms.Control(VControl xc) {
			return (xc == null)? null : xc.c;
		}

		public static implicit operator System.Windows.Forms.Button(VControl xc) {
			return (xc == null)? null : (System.Windows.Forms.Button)(xc.c);
		}

		public static implicit operator System.Windows.Forms.CheckBox(VControl xc) {
			return (xc == null)? null : (System.Windows.Forms.CheckBox)(xc.c);
		}

		public static implicit operator System.Windows.Forms.CheckedListBox(VControl xc) {
			return (xc == null)? null : (System.Windows.Forms.CheckedListBox)(xc.c);
		}

		public static implicit operator System.Windows.Forms.ComboBox(VControl xc) {
			return (xc == null)? null : (System.Windows.Forms.ComboBox)(xc.c);
		}

		public static implicit operator System.Windows.Forms.DomainUpDown(VControl xc) {
			return (xc == null)? null : (System.Windows.Forms.DomainUpDown)(xc.c);
		}

		public static implicit operator System.Windows.Forms.Form(VControl xc) {
			return (xc == null)? null : (System.Windows.Forms.Form)(xc.c);
		}

		public static implicit operator System.Windows.Forms.GroupBox(VControl xc) {
			return (xc == null)? null : (System.Windows.Forms.GroupBox)(xc.c);
		}

		public static implicit operator System.Windows.Forms.Label(VControl xc) {
			return (xc == null)? null : (System.Windows.Forms.Label)(xc.c);
		}

		public static implicit operator System.Windows.Forms.ListBox(VControl xc) {
			return (xc == null)? null : (System.Windows.Forms.ListBox)(xc.c);
		}

		public static implicit operator System.Windows.Forms.Panel(VControl xc) {
			return (xc == null)? null : (System.Windows.Forms.Panel)(xc.c);
		}

		public static implicit operator System.Windows.Forms.PictureBox(VControl xc) {
			return (xc == null)? null : (System.Windows.Forms.PictureBox)(xc.c);
		}

		public static implicit operator System.Windows.Forms.ProgressBar(VControl xc) {
			return (xc == null)? null : (System.Windows.Forms.ProgressBar)(xc.c);
		}

		public static implicit operator System.Windows.Forms.TextBox(VControl xc) {
			return (xc == null)? null : (System.Windows.Forms.TextBox)(xc.c);
		}

		public static implicit operator System.Windows.Forms.TrackBar(VControl xc) {
			return (xc == null)? null : (System.Windows.Forms.TrackBar)(xc.c);
		}

	} // class VControl

	// Struct to keep track of which controls and groups are
	// nested inside a form/vertical/horizontal/panel/groupbox group
	public class VGroup : VControl {
		public ArrayList m;	// the list of members of the group

		public VGroup(string t) : this() {
			tag = t;
		}

		public VGroup( ) {
			m = new ArrayList();
		}

		public override string ToString() {
			return String.Format("VGroup (tag={0})",tag);
		}
	}

	public class ViewsException : System.Exception {
		public ViewsException( string message ) :
			base("Views Exception: "+message) {
		}
		public ViewsException( string message, Exception inner ) :
			base("Views Exception: "+message, inner) {
		}
		public override string ToString() {
			return Message;
		}
	}

} // namespace Views
